@@ -62,6 +62,7 @@
 #'   training folds to calculate performance on outer training folds.
 #' @param returnList Logical whether to return list of results after main outer
 #'   CV loop without concatenating results. Useful for debugging.
+#' @param final Logical whether to fit final model.
 #' @param na.option Character value specifying how `NA`s are dealt with.
 #'   `"omit"` is equivalent to `na.action = na.omit`. `"omitcol"` removes cases
 #'   if there are `NA` in 'y', but columns (predictors) containing `NA` are
@@ -87,7 +88,6 @@
 #'   \item{outer_folds}{List of indices of outer test folds}
 #'   \item{final_fit}{Final fitted model on whole data}
 #'   \item{final_vars}{Column names of filtered predictors entering final model}
-#'   \item{summary_vars}{Summary statistics of filtered predictors}
 #'   \item{roc}{ROC AUC for binary classification where available.}
 #'   \item{summary}{Overall performance summary. Accuracy and balanced accuracy
 #'   for classification. ROC AUC for binary classification. RMSE for
@@ -202,8 +202,9 @@ outercv.default <- function(y, x,
                             multicore_fork = (Sys.info()["sysname"] != "Windows"),
                             predict_type = "prob",
                             outer_train_predict = FALSE,
-                            na.option = "pass",
                             returnList = FALSE,
+                            final = TRUE,
+                            na.option = "pass",
                             verbose = FALSE,
                             suppressMsg = verbose,
                             ...) {
@@ -233,7 +234,8 @@ outercv.default <- function(y, x,
   if (outercv.call$model == "glm") predict_type <- "response"
   if (outercv.call$model == "mda") predict_type <- "posterior"
   
-  if (verbose && (!multicore_fork || Sys.getenv("RSTUDIO") == "1")) {
+  verbose <- as.numeric(verbose)
+  if (verbose == 1 && (!multicore_fork || Sys.getenv("RSTUDIO") == "1")) {
     message("Performing ", n_outer_folds, "-fold outer CV, using ",
             plural(cv.cores, "core(s)"))}
   
@@ -306,36 +308,38 @@ outercv.default <- function(y, x,
   }
   
   # fit final model
-  if (verbose) message("Fitting final model on whole data")
-  dat <- nest_filt_bal(NULL, y, x, filterFUN, filter_options,
-                       balance, balance_options,
-                       modifyX, modifyX_useY, modifyX_options)
-  yfinal <- dat$ytrain
-  filtx <- dat$filt_xtrain
-  
-  if ("formula" %in% formalArgs(model)) {
-    dat <- if (is.data.frame(filtx)) {filtx
-    } else as.data.frame(filtx, stringsAsFactors = TRUE)
-    dat$.outcome <- yfinal
-    if (is.null(weights)) {
-      args <- c(list(as.formula(".outcome ~ ."), data = quote(dat)), dots)
+  if (final) {
+    if (verbose == 1) message("Fitting final model on whole data")
+    dat <- nest_filt_bal(NULL, y, x, filterFUN, filter_options,
+                         balance, balance_options,
+                         modifyX, modifyX_useY, modifyX_options)
+    yfinal <- dat$ytrain
+    filtx <- dat$filt_xtrain
+    
+    if ("formula" %in% formalArgs(model)) {
+      dat <- if (is.data.frame(filtx)) {filtx
+      } else as.data.frame(filtx, stringsAsFactors = TRUE)
+      dat$.outcome <- yfinal
+      if (is.null(weights)) {
+        args <- c(list(as.formula(".outcome ~ ."), data = quote(dat)), dots)
+      } else {
+        args <- c(list(as.formula(".outcome ~ ."), data = quote(dat),
+                       weights = quote(weights)), dots)
+      }
     } else {
-      args <- c(list(as.formula(".outcome ~ ."), data = quote(dat),
-                   weights = quote(weights)), dots)
+      if (is.null(weights)) {
+        args <- c(alist(y = yfinal, x = filtx), dots)  # prevents evaluation
+      } else {
+        args <- c(alist(y = yfinal, x = filtx, weights = weights), dots)
+      }
     }
-  } else {
-    if (is.null(weights)) {
-      args <- c(alist(y = yfinal, x = filtx), dots)  # prevents evaluation
-    } else {
-      args <- c(alist(y = yfinal, x = filtx, weights = weights), dots)
-    }
-  }
-  if (suppressMsg) {
-    printlog <- capture.output({ fit <- do.call(model, args) })
-  } else fit <- do.call(model, args)
+    if (suppressMsg) {
+      printlog <- capture.output({ fit <- do.call(model, args) })
+    } else fit <- do.call(model, args)
+  } else yfinal <- fit <- filtx <- NULL
   
   end <- Sys.time()
-  if (verbose) message("Duration: ", format(end - start))
+  if (verbose == 1) message("Duration: ", format(end - start))
   out <- list(call = outercv.call,
               output = output,
               outer_result = outer_res,
@@ -346,10 +350,9 @@ outercv.default <- function(y, x,
               yfinal = yfinal,
               final_fit = fit,
               final_vars = colnames(filtx),
-              summary_vars = summary_vars(filtx),
               roc = fit.roc,
               summary = summary)
-  if (!is.null(modifyX)) {
+  if (final && !is.null(modifyX)) {
     out$xfinal <- filtx
     if (modifyX_useY) out$modify_fit <- dat$modify_fit
   }
@@ -424,10 +427,10 @@ outercvCore <- function(i, y, x, outer_folds, model, reg,
     }
   } else train_preds <- NULL
   
-  if (verbose) {
+  if (verbose == 1) {
     end <- Sys.time()
     message_parallel("Fitted fold ", i, " (", format(end - start, digits = 3), ")")
-  }
+  } else if (verbose == 2) cat_parallel("=")
   
   list(preds = preds,
        train_preds = train_preds,
@@ -480,7 +483,8 @@ outercv.formula <- function(formula, data,
     return(out)
   }
   # for models designed for formula method
-  if (verbose && (!multicore_fork || Sys.getenv("RSTUDIO") == "1")) {
+  verbose <- as.numeric(verbose)
+  if (verbose == 1 && (!multicore_fork || Sys.getenv("RSTUDIO") == "1")) {
     message("Performing ", n_outer_folds, "-fold outer CV, using ",
             plural(cv.cores, "core(s)"))}
   
@@ -533,14 +537,14 @@ outercv.formula <- function(formula, data,
   }
   
   # fit final model
-  if (verbose) message("Fitting final model on whole data")
+  if (verbose == 1) message("Fitting final model on whole data")
   args <- c(list(formula = formula, data = quote(data)), dots)
   if (suppressMsg) {
     printlog <- capture.output({ fit <- do.call(model, args) })
   } else fit <- do.call(model, args)
   
   end <- Sys.time()
-  if (verbose) message("Duration: ", format(end - start))
+  if (verbose == 1) message("Duration: ", format(end - start))
   
   out <- list(call = outercv.call,
               output = output,
@@ -550,7 +554,6 @@ outercv.formula <- function(formula, data,
               dimx = c(nrow(data), length(labels(terms(fit)))),
               final_fit = fit,
               y = y,
-              summary_vars = summary_vars(data),
               roc = fit.roc,
               summary = summary)
   class(out) <- "outercv"
@@ -591,10 +594,10 @@ outercvFormulaCore <- function(i, outer_folds, formula, data, y, model,
     rownames(train_preds) <- rownames(data)[-test]
   } else train_preds <- NULL
   
-  if (verbose) {
+  if (verbose == 1) {
     end <- Sys.time()
     message_parallel("Fitted fold ", i, " (", format(end - start, digits = 3), ")")
-  }
+  } else if (verbose == 2) cat_parallel("=")
   
   list(preds = preds,
        train_preds = train_preds,
